<p align="center">
<img src="./ice-launcher.png" alt="Ice Launcher Logo" height="128px">
</p>

<h1 align="center">Ice Launcher</h1>

<p align="center">
<a href="https://github.com/mq1/ice-launcher/blob/main/LICENSE"><img alt="License: GPL-3.0" src="https://img.shields.io/github/license/mq1/ice-launcher"></a>
<a href="https://github.com/psf/black"><img alt="Code style: black" src="https://img.shields.io/badge/code%20style-black-000000.svg"></a>
</p>

-----

An unofficial WIP Minecraft Launcher

**Table of Contents**

- [Installation](#installation)
- [Thanks](#thanks)
- [License](#license)

## Installation

### Package (recommended)

Just grab the [latest release](https://github.com/mq1/ice-launcher/releases/latest) for your platform

### From pip

```sh
pip install ice-launcher
```

## Thanks

- Aru for the awesome logo!
- [JakobDev](https://gitlab.com/JakobDev) for building [minecraft-launcher-lib](https://gitlab.com/JakobDev/minecraft-launcher-lib)
- [TomSchimansky](https://github.com/TomSchimansky) for building [CustomTkinter](https://github.com/TomSchimansky/CustomTkinter)

## License

`ice-launcher` is distributed under the terms of the [GPL-3.0-only](https://spdx.org/licenses/GPL-3.0-only.html) license.
